
Command-line tool to compute thermodynamic quantities from netCDF4 files.

It requires a thermodynamic data file (table of values) produced by a 
data file generator that relies on the ``pyteos_air`` package:



VERSION HISTORY
^^^^^^^^^^^^^^^

0.4.1: Bug fix.

0.4 : Clean-up PYPI repository.

0.3 : Added some pre-cooked recipes

0.2 : Finished disentangling from ``pyteos_air``

Frederic Laliberte, March 2017
